@@ -1,7 +1,5 @@
 package Poet::Log;
-BEGIN {
-  $Poet::Log::VERSION = '0.12';
-}
+$Poet::Log::VERSION = '0.14';
 use Poet qw($conf $poet);
 use File::Spec::Functions qw(rel2abs);
 use Log::Any::Adapter;
@@ -71,8 +69,7 @@ method generate_log4perl_config ($class:) {
         "\n",
         $class->_generate_lines( 'log4perl.logger', 'default', \%defaults ),
         map {
-            $class->_generate_lines( "log4perl.logger.$_",
-                $class->_flatten_class_name($_),
+            $class->_generate_lines( "log4perl.logger.$_", $class->_flatten_class_name($_),
                 $classes{$_} )
         } sort( keys(%classes) ),
     );
@@ -81,9 +78,9 @@ method generate_log4perl_config ($class:) {
 method _generate_lines ($class: $logger, $appender, $set) {
     my $full_appender = "log4perl.appender.$appender";
     my @pairs         = (
-        [ $logger => join( ", ", uc( $set->{level} ), $appender ) ],
-        [ $full_appender          => $set->{appender_class} ],
-        [ "$full_appender.layout" => 'Log::Log4perl::Layout::PatternLayout' ],
+        [ $logger        => join( ", ", uc( $set->{level} ), $appender ) ],
+        [ $full_appender => $set->{appender_class} ],
+        [ "$full_appender.layout"                   => 'Log::Log4perl::Layout::PatternLayout' ],
         [ "$full_appender.layout.ConversionPattern" => $set->{layout} ]
     );
     foreach my $key (qw(filename stderr)) {
@@ -103,7 +100,7 @@ method _flatten_class_name ($class: $class_name) {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -119,7 +116,7 @@ Poet::Log -- Poet logging
         level: info
         output: poet.log
         layout: "%d{dd/MMM/yyyy:HH:mm:ss.SS} [%p] %c - %m - %F:%L - %P%n"
-      category:
+      class:
         CHI:
           level: debug
           output: chi.log
@@ -315,7 +312,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
