@@ -1,7 +1,5 @@
-package Poet::Mason;
-BEGIN {
-  $Poet::Mason::VERSION = '0.12';
-}    ## no critic (Moose::RequireMakeImmutable)
+package Poet::Mason;    ## no critic (Moose::RequireMakeImmutable)
+$Poet::Mason::VERSION = '0.14';
 use Poet qw($conf $poet);
 use List::MoreUtils qw(uniq);
 use Method::Signatures::Simple;
@@ -32,9 +30,7 @@ method get_options ($class:) {
     my $extra_plugins = $conf->get_list("mason.extra_plugins");
     delete( $configured{extra_plugins} );
     my %options = ( %defaults, %configured );
-    $options{plugins} =
-      [ uniq( @{ $options{plugins} }, '+Poet::Mason::Plugin', @$extra_plugins )
-      ];
+    $options{plugins} = [ uniq( @{ $options{plugins} }, '+Poet::Mason::Plugin', @$extra_plugins ) ];
     return %options;
 }
 
@@ -44,17 +40,16 @@ method get_plugins ($class:) {
 
 method handle_psgi ($class: $psgi_env) {
     my $req      = $poet->app_class('Plack::Request')->new($psgi_env);
+    my $res      = $poet->app_class('Plack::Response')->new();
     my $response = try {
         my $interp = $poet->app_class('Mason')->instance;
-        my $m = $interp->_make_request( req => $req );
-        $m->run( $class->_psgi_comp_path($req),
-            $class->_psgi_parameters($req) );
+        my $m = $interp->_make_request( req => $req, res => $res );
+        $m->run( $class->_psgi_comp_path($req), $class->_psgi_parameters($req) );
         $m->res;
     }
     catch {
         my $err = $_;
-        if ( blessed($err) && $err->isa('Mason::Exception::TopLevelNotFound') )
-        {
+        if ( blessed($err) && $err->isa('Mason::Exception::TopLevelNotFound') ) {
             $poet->app_class('Plack::Response')->new(404);
         }
         else {
@@ -79,7 +74,7 @@ method _psgi_parameters ($class: $req) {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -287,7 +282,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
