@@ -1,9 +1,8 @@
 package Poet::Server;
-BEGIN {
-  $Poet::Server::VERSION = '0.13';
-}
+$Poet::Server::VERSION = '0.14';
 use Poet qw($conf $poet);
 use Method::Signatures::Simple;
+use Class::Load;
 use Class::MOP;
 use strict;
 use warnings;
@@ -44,7 +43,7 @@ my $loaded_startup_modules;
 method load_startup_modules () {
     return if $loaded_startup_modules++;
     foreach my $module ( @{ $conf->get_list('server.load_modules') } ) {
-        Class::MOP::load_class($module);
+        Class::Load::load_class($module);
     }
 }
 
