@@ -1,10 +1,9 @@
 # Internal Poet tools
 #
 package Poet::Tools;
-BEGIN {
-  $Poet::Tools::VERSION = '0.13';
-}
+$Poet::Tools::VERSION = '0.14';
 use Carp;
+use Class::Load;
 use Class::MOP;
 use Config;
 use Fcntl qw( :DEFAULT :seek );
@@ -35,7 +34,7 @@ sub can_load {
 
     my $result;
     try {
-        Class::MOP::load_class($class_name);
+        Class::Load::load_class($class_name);
         $result = 1;
     }
     catch {
