@@ -1,7 +1,5 @@
 package Poet::Util::Debug;
-BEGIN {
-  $Poet::Util::Debug::VERSION = '0.12';
-}
+$Poet::Util::Debug::VERSION = '0.14';
 use Carp qw(longmess);
 use Data::Dumper;
 use strict;
@@ -18,11 +16,10 @@ sub _dump_value_with_caller {
     my ( $value, $func_name ) = @_;
 
     my $dump =
-      Data::Dumper->new( [$value] )->Indent(1)->Sortkeys(1)->Quotekeys(0)
-      ->Terse(1)->Dump();
+      Data::Dumper->new( [$value] )->Indent(1)->Sortkeys(1)->Quotekeys(0)->Terse(1)->Dump();
     my @caller = caller(1);
-    return sprintf( "[%s at %s line %d.] [%d] %s\n",
-        $func_name, $caller[1], $caller[2], $$, $dump );
+    return
+      sprintf( "[%s at %s line %d.] [%d] %s\n", $func_name, $caller[1], $caller[2], $$, $dump );
 }
 
 sub _define {
@@ -52,8 +49,7 @@ sub _define {
 _define(
     'dc',
     sub {
-        $console_log ||=
-          Poet::Environment->current_env->logs_path("console.log");
+        $console_log ||= Poet::Environment->current_env->logs_path("console.log");
         open( my $fh, ">>", $console_log );
         $fh->print( $_[0] );
     }
@@ -82,7 +78,7 @@ _define(
 
 1;
 
-
+__END__
 
 =pod
 
@@ -201,7 +197,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
